sel.best.window: Selection of the best window computed with cv.wpls
Description
Takes as input the object containing metrics of the several models computed
with cv.wpls and selects the best basing on the lowest RMSE available; then computes
PLS and gives as output an object containing results.
Usage
sel.best.window(wpls = NULL)
Value
An object containing results of the best model. Has the same content of a model obtained from the function pls of mdatools.